==> pipewire-docs-1%3A0.3.84-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__types.js <==
var group__spa__types =
[
    [ "type-info.h", "utils_2type-info_8h.html", null ],
    [ "type.h", "spa_2include_2spa_2utils_2type_8h.html", null ],
    [ "spa_type_info", "structspa__type__info.html", [
      [ "type", "structspa__type__info.html#a25dfe56fe53d756509cd5daa5f5b64e5", null ],
      [ "parent", "structspa__type__info.html#ab94f9983f18d62536d03ba5eb7db9bae", null ],
      [ "values", "structspa__type__info.html#afedc2465e18bf4d93bf2a3d8afcc4c13", null ]
    ] ],
    [ "SPA_TYPE_ROOT", "group__spa__types.html#gafbabcef02a8226b94cd9708d0e3bda6c", null ],
    [ "SPA_TYPE_INFO_BASE", "group__spa__types.html#ga12e7f34d2ebf7bb4ad1b14997148383f", null ],
    [ "SPA_TYPE_INFO_Flags", "group__spa__types.html#ga886514f37da7215fa5eebe406e2f3b37", null ],
    [ "SPA_TYPE_INFO_FLAGS_BASE", "group__spa__types.html#gad9c69f01ba4f4907c8550164be6d3d49", null ],
    [ "SPA_TYPE_INFO_Enum", "group__spa__types.html#ga7991023e0704b7af71b19a08c4a023b7", null ],
    [ "SPA_TYPE_INFO_ENUM_BASE", "group__spa__types.html#gaa055f9a506370480ced82ad6cccf13db", null ],
    [ "SPA_TYPE_INFO_Pod", "group__spa__types.html#ga94dcb50c9935bbe4cbfa8b229dca36ce", null ],
    [ "SPA_TYPE_INFO_POD_BASE", "group__spa__types.html#ga4aae17a0b82f8be6d450a8fa3a102225", null ],
    [ "SPA_TYPE_INFO_Struct", "group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf", null ],
    [ "SPA_TYPE_INFO_STRUCT_BASE", "group__spa__types.html#ga9e1a81c8210e152df8ef719874f50966", null ],
    [ "SPA_TYPE_INFO_Object", "group__spa__types.html#gaecaf5a9f0c1bd9c31611d0fdf18fe7a2", null ],
    [ "SPA_TYPE_INFO_OBJECT_BASE", "group__spa__types.html#ga4fabe70032a577729bfaa7e1cb231ac6", null ],
    [ "SPA_TYPE_INFO_Pointer", "group__spa__types.html#ga8d234c1fa75de54561de75610f091efa", null ],
    [ "SPA_TYPE_INFO_POINTER_BASE", "group__spa__types.html#gad3685dd5b8d7658dd24b77fad4a721bc", null ],
    [ "SPA_TYPE_INFO_Interface", "group__spa__types.html#gacca81d9bddca49922a0945a9b58b5e39", null ],
    [ "SPA_TYPE_INFO_INTERFACE_BASE", "group__spa__types.html#ga2262de66172c201319e7336253600f31", null ],
    [ "SPA_TYPE_INFO_Event", "group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf", null ],
    [ "SPA_TYPE_INFO_EVENT_BASE", "group__spa__types.html#ga0c6d1b17fc516da2e38cea3e1c7c859c", null ],
    [ "SPA_TYPE_INFO_Command", "group__spa__types.html#ga9f782261111d9f99e61840289e47e8e3", null ],
    [ "SPA_TYPE_INFO_COMMAND_BASE", "group__spa__types.html#gafed08c224994e5fa76c5503bd4e476dd", [
      [ "SPA_TYPE_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635affe6056769241bea4ffa3e785e5e401b", null ],
      [ "SPA_TYPE_None", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a6b256812f3b819d23d240f76d70e2dbf", null ],
      [ "SPA_TYPE_Bool", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a24ed5d9833f99909fa26f7a890a08279", null ],
      [ "SPA_TYPE_Id", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9a2a2e8cb5faaf866964031cdd971f1e", null ],
      [ "SPA_TYPE_Int", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a08878f07dded510b5965257093dd604e", null ],
      [ "SPA_TYPE_Long", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1e89cacd1810c67cd3b3d3da62dbc547", null ],
      [ "SPA_TYPE_Float", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a5905ea737f42cc92167be9bf93dfd167", null ],
      [ "SPA_TYPE_Double", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a86e076cabebe3b2ec39b4d912aa01003", null ],
      [ "SPA_TYPE_String", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635acc90a6eabfa60bb2a3b9edbdedb0780a", null ],
      [ "SPA_TYPE_Bytes", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a39b08d57355f457b217ab61fdf6fbbb2", null ],
      [ "SPA_TYPE_Rectangle", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1b7df4cd68f31054312855f165285edf", null ],
      [ "SPA_TYPE_Fraction", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a68dcb230a92b33114c4aed662c02d50a", null ],
      [ "SPA_TYPE_Bitmap", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a4fa853cb56b0175c4473a18fede3f3b4", null ],
      [ "SPA_TYPE_Array", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab2f26930a251f5d048dfebcc46e4f736", null ],
      [ "SPA_TYPE_Struct", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635afae023d5557f54aad58d6690a3098752", null ],
      [ "SPA_TYPE_Object", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a52695c8e36490cd296076d6891e32262", null ],
      [ "SPA_TYPE_Sequence", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a81a29f07db632a54033e5462c62d390e", null ],
      [ "SPA_TYPE_Pointer", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aae8ab14cce66fd8093d9a8e24194d276", null ],
      [ "SPA_TYPE_Fd", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635adce948c3f0669e100c3fd2f2d26bebd6", null ],
      [ "SPA_TYPE_Choice", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aa18b83a008ed25d20510c57ae28c19b0", null ],
      [ "SPA_TYPE_Pod", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a3ebe799703abfff387797587bbfad3e3", null ],
      [ "_SPA_TYPE_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a74f4d538e5505aed6fc795ce42b428cd", null ],
      [ "SPA_TYPE_POINTER_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a14f9bce34113fee61a81ccaea5b6677b", null ],
      [ "SPA_TYPE_POINTER_Buffer", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a0167cc2e8efa1a4b616e72c738bc1b3a", null ],
      [ "SPA_TYPE_POINTER_Meta", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ad2998c81218b9d9637b0623d786da71b", null ],
      [ "SPA_TYPE_POINTER_Dict", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a58faecf8df50f261bbc3a8e28b85b794", null ],
      [ "_SPA_TYPE_POINTER_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af64dcbfbabdf6f2529ab10eee233a25f", null ],
      [ "SPA_TYPE_EVENT_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aa0cfc07bb96adcab746031c438a116a0", null ],
      [ "SPA_TYPE_EVENT_Device", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a3d2745730c4bfca49691586d603fe6ec", null ],
      [ "SPA_TYPE_EVENT_Node", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aac9b68fa1908cfe871bcf6f2848b5791", null ],
      [ "_SPA_TYPE_EVENT_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab86413edcf3bc9ba4454e49c451d5c9e", null ],
      [ "SPA_TYPE_COMMAND_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1195438b5c43f33a3fe50accde463f9b", null ],
      [ "SPA_TYPE_COMMAND_Device", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a5a0fa022316ba443e8a96d8ebd5a74da", null ],
      [ "SPA_TYPE_COMMAND_Node", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ad9a1d2a985cbf63762ad5314a148fc8e", null ],
      [ "_SPA_TYPE_COMMAND_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ad9368eac91f702bab0607906ccaca2b7", null ],
      [ "SPA_TYPE_OBJECT_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a427f4561941dabbebc3886ff2264e454", null ],
      [ "SPA_TYPE_OBJECT_PropInfo", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a4075755bc655b04188844f6cd702733d", null ],
      [ "SPA_TYPE_OBJECT_Props", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a7ed21b2ab0922a9b7b7418e27037b9be", null ],
      [ "SPA_TYPE_OBJECT_Format", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aff40c8f7d5f7228694ad59007df53867", null ],
      [ "SPA_TYPE_OBJECT_ParamBuffers", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a618e317af0356e6d4a1fe40b67d28f9e", null ],
      [ "SPA_TYPE_OBJECT_ParamMeta", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aec5c97a09714cacc72bfe01732f1783c", null ],
      [ "SPA_TYPE_OBJECT_ParamIO", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a73849a477ad593eabbd5c08bec295d84", null ],
      [ "SPA_TYPE_OBJECT_ParamProfile", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a0d689fa3897dcc16fdeb08814cb251ca", null ],
      [ "SPA_TYPE_OBJECT_ParamPortConfig", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a07c6c317beb0840af6c989b35e497e94", null ],
      [ "SPA_TYPE_OBJECT_ParamRoute", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af25926b5d489ddd2acb63ea263c78e92", null ],
      [ "SPA_TYPE_OBJECT_Profiler", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9134670bb87389f183503125e1f9145d", null ],
      [ "SPA_TYPE_OBJECT_ParamLatency", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9917f2715796d0cabc77ea3f7db161ac", null ],
      [ "SPA_TYPE_OBJECT_ParamProcessLatency", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635adad41b7daa68add7b035c5df2c84d7a0", null ],
      [ "SPA_TYPE_OBJECT_ParamTag", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aeee6774ed404e67281d3dd515621545c", null ],
      [ "_SPA_TYPE_OBJECT_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab0d0e30c07c9d934c96bc2210183537b", null ],
      [ "SPA_TYPE_VENDOR_PipeWire", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635acfb1d7904ddafd3c67dcdd49410bb05a", null ],
      [ "SPA_TYPE_VENDOR_Other", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a3b923c5f09c56b563d4d5bf4ab2a4cb0", null ]
    ] ],
    [ "spa_type_is_a", "group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3", null ],
    [ "spa_types", "group__spa__types.html#gafb8bf694625474ebfb1ecdce28bb4828", null ]
];

==> pipewire-docs-1%3A1.2.3-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__types.js <==
var group__spa__types =
[
    [ "enum-types.h", "enum-types_8h.html", null ],
    [ "type-info.h", "utils_2type-info_8h.html", null ],
    [ "type.h", "spa_2include_2spa_2utils_2type_8h.html", null ],
    [ "spa_type_info", "structspa__type__info.html", [
      [ "type", "structspa__type__info.html#a25dfe56fe53d756509cd5daa5f5b64e5", null ],
      [ "parent", "structspa__type__info.html#ab94f9983f18d62536d03ba5eb7db9bae", null ],
      [ "values", "structspa__type__info.html#afedc2465e18bf4d93bf2a3d8afcc4c13", null ],
      [ "SPA_TYPE_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635affe6056769241bea4ffa3e785e5e401b", null ],
      [ "SPA_TYPE_None", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a6b256812f3b819d23d240f76d70e2dbf", null ],
      [ "SPA_TYPE_Bool", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a24ed5d9833f99909fa26f7a890a08279", null ],
      [ "SPA_TYPE_Id", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9a2a2e8cb5faaf866964031cdd971f1e", null ],
      [ "SPA_TYPE_Int", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a08878f07dded510b5965257093dd604e", null ],
      [ "SPA_TYPE_Long", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1e89cacd1810c67cd3b3d3da62dbc547", null ],
      [ "SPA_TYPE_Float", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a5905ea737f42cc92167be9bf93dfd167", null ],
      [ "SPA_TYPE_Double", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a86e076cabebe3b2ec39b4d912aa01003", null ],
      [ "SPA_TYPE_String", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635acc90a6eabfa60bb2a3b9edbdedb0780a", null ],
      [ "SPA_TYPE_Bytes", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a39b08d57355f457b217ab61fdf6fbbb2", null ],
      [ "SPA_TYPE_Rectangle", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1b7df4cd68f31054312855f165285edf", null ],
      [ "SPA_TYPE_Fraction", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a68dcb230a92b33114c4aed662c02d50a", null ],
      [ "SPA_TYPE_Bitmap", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a4fa853cb56b0175c4473a18fede3f3b4", null ],
      [ "SPA_TYPE_Array", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab2f26930a251f5d048dfebcc46e4f736", null ],
      [ "SPA_TYPE_Struct", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635afae023d5557f54aad58d6690a3098752", null ],
      [ "SPA_TYPE_Object", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a52695c8e36490cd296076d6891e32262", null ],
      [ "SPA_TYPE_Sequence", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a81a29f07db632a54033e5462c62d390e", null ],
      [ "SPA_TYPE_Pointer", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aae8ab14cce66fd8093d9a8e24194d276", null ],
      [ "SPA_TYPE_Fd", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635adce948c3f0669e100c3fd2f2d26bebd6", null ],
      [ "SPA_TYPE_Choice", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aa18b83a008ed25d20510c57ae28c19b0", null ],
      [ "SPA_TYPE_Pod", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a3ebe799703abfff387797587bbfad3e3", null ],
      [ "_SPA_TYPE_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a74f4d538e5505aed6fc795ce42b428cd", null ],
      [ "SPA_TYPE_POINTER_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a14f9bce34113fee61a81ccaea5b6677b", null ],
      [ "SPA_TYPE_POINTER_Buffer", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a0167cc2e8efa1a4b616e72c738bc1b3a", null ],
      [ "SPA_TYPE_POINTER_Meta", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ad2998c81218b9d9637b0623d786da71b", null ],
      [ "SPA_TYPE_POINTER_Dict", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a58faecf8df50f261bbc3a8e28b85b794", null ],
      [ "_SPA_TYPE_POINTER_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af64dcbfbabdf6f2529ab10eee233a25f", null ],
      [ "SPA_TYPE_EVENT_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aa0cfc07bb96adcab746031c438a116a0", null ],
      [ "SPA_TYPE_EVENT_Device", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a3d2745730c4bfca49691586d603fe6ec", null ],
      [ "SPA_TYPE_EVENT_Node", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aac9b68fa1908cfe871bcf6f2848b5791", null ],
      [ "_SPA_TYPE_EVENT_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab86413edcf3bc9ba4454e49c451d5c9e", null ],
      [ "SPA_TYPE_COMMAND_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1195438b5c43f33a3fe50accde463f9b", null ],
      [ "SPA_TYPE_COMMAND_Device", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a5a0fa022316ba443e8a96d8ebd5a74da", null ],
      [ "SPA_TYPE_COMMAND_Node", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ad9a1d2a985cbf63762ad5314a148fc8e", null ],
      [ "_SPA_TYPE_COMMAND_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ad9368eac91f702bab0607906ccaca2b7", null ],
      [ "SPA_TYPE_OBJECT_START", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a427f4561941dabbebc3886ff2264e454", null ],
      [ "SPA_TYPE_OBJECT_PropInfo", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a4075755bc655b04188844f6cd702733d", null ],
      [ "SPA_TYPE_OBJECT_Props", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a7ed21b2ab0922a9b7b7418e27037b9be", null ],
      [ "SPA_TYPE_OBJECT_Format", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aff40c8f7d5f7228694ad59007df53867", null ],
      [ "SPA_TYPE_OBJECT_ParamBuffers", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a618e317af0356e6d4a1fe40b67d28f9e", null ],
      [ "SPA_TYPE_OBJECT_ParamMeta", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aec5c97a09714cacc72bfe01732f1783c", null ],
      [ "SPA_TYPE_OBJECT_ParamIO", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a73849a477ad593eabbd5c08bec295d84", null ],
      [ "SPA_TYPE_OBJECT_ParamProfile", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a0d689fa3897dcc16fdeb08814cb251ca", null ],
      [ "SPA_TYPE_OBJECT_ParamPortConfig", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a07c6c317beb0840af6c989b35e497e94", null ],
      [ "SPA_TYPE_OBJECT_ParamRoute", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af25926b5d489ddd2acb63ea263c78e92", null ],
      [ "SPA_TYPE_OBJECT_Profiler", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9134670bb87389f183503125e1f9145d", null ],
      [ "SPA_TYPE_OBJECT_ParamLatency", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9917f2715796d0cabc77ea3f7db161ac", null ],
      [ "SPA_TYPE_OBJECT_ParamProcessLatency", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635adad41b7daa68add7b035c5df2c84d7a0", null ],
      [ "SPA_TYPE_OBJECT_ParamTag", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aeee6774ed404e67281d3dd515621545c", null ],
      [ "_SPA_TYPE_OBJECT_LAST", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab0d0e30c07c9d934c96bc2210183537b", null ],
      [ "SPA_TYPE_VENDOR_PipeWire", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635acfb1d7904ddafd3c67dcdd49410bb05a", null ],
      [ "SPA_TYPE_VENDOR_Other", "group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a3b923c5f09c56b563d4d5bf4ab2a4cb0", null ]
    ] ],
    [ "SPA_TYPE_INFO_Direction", "group__spa__types.html#gaaca7a372068124b38f09b0bd2fef0f98", null ],
    [ "SPA_TYPE_INFO_DIRECTION_BASE", "group__spa__types.html#gab8f02181d37e1c034e04797628a8ee1b", null ],
    [ "SPA_TYPE_INFO_Choice", "group__spa__types.html#gaaaa70c8c33c359627dd29efe58e62503", null ],
    [ "SPA_TYPE_INFO_CHOICE_BASE", "group__spa__types.html#ga21cc1e946168521828401b4b652c3318", null ],
    [ "SPA_TYPE_ROOT", "group__spa__types.html#gafbabcef02a8226b94cd9708d0e3bda6c", null ],
    [ "SPA_TYPE_INFO_BASE", "group__spa__types.html#ga12e7f34d2ebf7bb4ad1b14997148383f", null ],
    [ "SPA_TYPE_INFO_Flags", "group__spa__types.html#ga886514f37da7215fa5eebe406e2f3b37", null ],
    [ "SPA_TYPE_INFO_FLAGS_BASE", "group__spa__types.html#gad9c69f01ba4f4907c8550164be6d3d49", null ],
    [ "SPA_TYPE_INFO_Enum", "group__spa__types.html#ga7991023e0704b7af71b19a08c4a023b7", null ],
    [ "SPA_TYPE_INFO_ENUM_BASE", "group__spa__types.html#gaa055f9a506370480ced82ad6cccf13db", null ],
    [ "SPA_TYPE_INFO_Pod", "group__spa__types.html#ga94dcb50c9935bbe4cbfa8b229dca36ce", null ],
    [ "SPA_TYPE_INFO_POD_BASE", "group__spa__types.html#ga4aae17a0b82f8be6d450a8fa3a102225", null ],
    [ "SPA_TYPE_INFO_Struct", "group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf", null ],
    [ "SPA_TYPE_INFO_STRUCT_BASE", "group__spa__types.html#ga9e1a81c8210e152df8ef719874f50966", null ],
    [ "SPA_TYPE_INFO_Object", "group__spa__types.html#gaecaf5a9f0c1bd9c31611d0fdf18fe7a2", null ],
    [ "SPA_TYPE_INFO_OBJECT_BASE", "group__spa__types.html#ga4fabe70032a577729bfaa7e1cb231ac6", null ],
    [ "SPA_TYPE_INFO_Pointer", "group__spa__types.html#ga8d234c1fa75de54561de75610f091efa", null ],
    [ "SPA_TYPE_INFO_POINTER_BASE", "group__spa__types.html#gad3685dd5b8d7658dd24b77fad4a721bc", null ],
    [ "SPA_TYPE_INFO_Interface", "group__spa__types.html#gacca81d9bddca49922a0945a9b58b5e39", null ],
    [ "SPA_TYPE_INFO_INTERFACE_BASE", "group__spa__types.html#ga2262de66172c201319e7336253600f31", null ],
    [ "SPA_TYPE_INFO_Event", "group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf", null ],
    [ "SPA_TYPE_INFO_EVENT_BASE", "group__spa__types.html#ga0c6d1b17fc516da2e38cea3e1c7c859c", null ],
    [ "SPA_TYPE_INFO_Command", "group__spa__types.html#ga9f782261111d9f99e61840289e47e8e3", null ],
    [ "SPA_TYPE_INFO_COMMAND_BASE", "group__spa__types.html#gafed08c224994e5fa76c5503bd4e476dd", null ],
    [ "spa_type_is_a", "group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3", null ],
    [ "spa_type_direction", "group__spa__types.html#gafff747a1e17cacd06f036b94ad100aaa", null ],
    [ "spa_type_choice", "group__spa__types.html#ga3f8207af24a34e29769be91b720c5191", null ],
    [ "spa_types", "group__spa__types.html#gafb8bf694625474ebfb1ecdce28bb4828", null ]
];
